Author: cwittich
Date: Tue Mar 11 05:09:14 2014
New Revision: 62470
URL:
http://svn.reactos.org/svn/reactos?rev=62470&view=rev
Log:
[comctl32]
rename TBSTYLE_EX_UNDOC1 to TBSTYLE_EX_VERTICAL
Modified:
trunk/reactos/dll/win32/comctl32/toolbar.c
trunk/reactos/include/psdk/commctrl.h
trunk/reactos/include/reactos/wine/commctrl.h
Modified: trunk/reactos/dll/win32/comctl32/toolbar.c
URL:
http://svn.reactos.org/svn/reactos/trunk/reactos/dll/win32/comctl32/toolbar…
==============================================================================
--- trunk/reactos/include/psdk/commctrl.h [iso-8859-1] (original)
+++ trunk/reactos/include/psdk/commctrl.h [iso-8859-1] Tue Mar 11 05:09:14 2014
@@ -949,7 +949,6 @@
#define TBSTYLE_CUSTOMERASE 0x2000
#define TBSTYLE_REGISTERDROP 0x4000
#define TBSTYLE_TRANSPARENT 0x8000
-#define TBSTYLE_EX_DRAWDDARROWS 0x1
#define BTNS_BUTTON TBSTYLE_BUTTON
#define BTNS_SEP TBSTYLE_SEP
@@ -962,9 +961,12 @@
#define BTNS_SHOWTEXT 0x40
#define BTNS_WHOLEDROPDOWN 0x80
-#define TBSTYLE_EX_MIXEDBUTTONS 0x8
-#define TBSTYLE_EX_HIDECLIPPEDBUTTONS 0x10
-#define TBSTYLE_EX_DOUBLEBUFFER 0x80
+#define TBSTYLE_EX_DRAWDDARROWS 0x00000001
+#define TBSTYLE_EX_MULTICOLUMN 0x00000002
+#define TBSTYLE_EX_VERTICAL 0x00000004
+#define TBSTYLE_EX_MIXEDBUTTONS 0x00000008
+#define TBSTYLE_EX_HIDECLIPPEDBUTTONS 0x00000010 /* don't show partially obscured
buttons */
+#define TBSTYLE_EX_DOUBLEBUFFER 0x00000080 /* Double Buffer the toolbar */
typedef struct _NMTBCUSTOMDRAW {
NMCUSTOMDRAW nmcd;
Modified: trunk/reactos/include/reactos/wine/commctrl.h
URL:
http://svn.reactos.org/svn/reactos/trunk/reactos/include/reactos/wine/commc…
==============================================================================
--- trunk/reactos/include/reactos/wine/commctrl.h [iso-8859-1] (original)
+++ trunk/reactos/include/reactos/wine/commctrl.h [iso-8859-1] Tue Mar 11 05:09:14 2014
@@ -63,7 +63,6 @@
typedef LVFINDINFOW *LPLVFINDINFOW;
#define SB_SETBORDERS (WM_USER+5)
-#define TBSTYLE_EX_UNDOC1 0x00000004 /* similar to TBSTYLE_WRAPABLE */
/* these are undocumented and the names are guesses */
typedef struct
--- trunk/reactos/dll/win32/comctl32/toolbar.c [iso-8859-1] (original)
+++ trunk/reactos/dll/win32/comctl32/toolbar.c [iso-8859-1] Tue Mar 11 05:09:14 2014
@@ -205,7 +205,7 @@
/* Used to find undocumented extended styles */
#define TBSTYLE_EX_ALL (TBSTYLE_EX_DRAWDDARROWS | \
- TBSTYLE_EX_UNDOC1 | \
+ TBSTYLE_EX_VERTICAL | \
TBSTYLE_EX_MIXEDBUTTONS | \
TBSTYLE_EX_DOUBLEBUFFER | \
TBSTYLE_EX_HIDECLIPPEDBUTTONS)
@@ -1257,7 +1257,7 @@
* the toolbar wrapping on its own, it can use the TBSTYLE_WRAPABLE
* flag, and set the TBSTATE_WRAP flags manually on the appropriate items.
*
* Note: TBSTYLE_WRAPABLE or TBSTYLE_EX_UNDOC1 can be used also to allow
* vertical toolbar lists.
*/
@@ -1273,7 +1273,7 @@
/* no layout is necessary. Applications may use this style */
/* to perform their own layout on the toolbar. */
if( !(infoPtr->dwStyle & TBSTYLE_WRAPABLE) &&
- !(infoPtr->dwExStyle & TBSTYLE_EX_UNDOC1) ) return;
+ !(infoPtr->dwExStyle & TBSTYLE_EX_VERTICAL) ) return;
btnPtr = infoPtr->buttons;
x = infoPtr->nIndent;
@@ -3023,7 +3023,7 @@
cy = TOP_BORDER + infoPtr->nRows * infoPtr->nButtonHeight + BOTTOM_BORDER;
cx = parent_rect.right - parent_rect.left;
- if ((infoPtr->dwStyle & TBSTYLE_WRAPABLE) || (infoPtr->dwExStyle &
TBSTYLE_EX_UNDOC1))
+ if ((infoPtr->dwStyle & TBSTYLE_WRAPABLE) || (infoPtr->dwExStyle &
TBSTYLE_EX_VERTICAL))
{
TOOLBAR_LayoutToolbar(infoPtr);
InvalidateRect( infoPtr->hwndSelf, NULL, TRUE );
@@ -3333,7 +3333,7 @@
if (lpTbInfo == NULL)
return -1;
- /* MSDN documents a iImageLabel field added in Vista but it is not present in
+ /* MSDN documents an iImageLabel field added in Vista but it is not present in
* the headers and tests shows that even with comctl 6 Vista accepts only the
* original TBBUTTONINFO size
*/
@@ -4132,7 +4132,7 @@
{
/* separator */
nmtbr.tbButton.fsStyle = TBSTYLE_SEP;
- /* when inserting separators, iBitmap controls it's size.
+ /* when inserting separators, iBitmap controls its size.
0 sets default size (width) */
nmtbr.tbButton.iBitmap = 0;
}
@@ -1257,7 +1257,7 @@
* flag, and set the TBSTATE_WRAP flags manually on the appropriate items.
*
-* Note: TBSTYLE_WRAPABLE or TBSTYLE_EX_UNDOC1 can be used also to allow
+* Note: TBSTYLE_WRAPABLE or TBSTYLE_EX_VERTICAL can be used also to allow
* vertical toolbar lists.
*/
Modified: trunk/reactos/include/psdk/commctrl.h
URL:
http://svn.reactos.org/svn/reactos/trunk/reactos/include/psdk/commctrl.h?re…
==============================================================================